@@ -1,7 +1,6 @@
 package File::Open::NoCache::ReadOnly;
 
 # Author Nigel Horne: njh@bandsman.co.uk
-# Copyright (C) 2019 Nigel Horne
 
 # Usage is subject to licence terms.
 # The licence terms of this software are as follows:
@@ -17,15 +16,15 @@ use IO::AIO;
 
 =head1 NAME
 
-File::Open::NoCache::ReadOnly - Open a file and clear the cache afterward
+File::Open::NoCache::ReadOnly - Open a file and flush from memory on closing
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SUBROUTINES/METHODS
 
@@ -35,7 +34,7 @@ Open a file that will be read once sequentially and not again,
 optimising the cache accordingly.
 One use case is building a large database from smaller files that are
 only read in once,
-Once the file has been used it's a waste of RAM to keep it in cache.
+once the file has been used it's a waste of RAM to keep it in cache.
 
     use File::Open::NoCache::ReadOnly;
     my $fh = File::Open::NoCache::ReadOnly->new('/etc/passwd');
@@ -63,16 +62,16 @@ sub new {
 	if(my $filename = $params{'filename'}) {
 		if(open(my $fd, '<', $filename)) {
 			IO::AIO::fadvise($fd, 0, 0, IO::AIO::FADV_SEQUENTIAL|IO::AIO::FADV_NOREUSE|IO::AIO::FADV_DONTNEED);
-			return bless { fd => $fd }, $class
+			return bless { fd => $fd }, $class;
 		}
 		if($params{'fatal'}) {
 			Carp::croak("$filename: $!");
 		}
 		Carp::carp("$filename: $!");
-		return;
+	} else {
+		Carp::carp('Usage: ', __PACKAGE__, '->new(filename => $filename)');
 	}
-	Carp::carp('Usage: ', __PACKAGE__, '->new(filename => $filename)');
-	return;
+	return;	# return undef
 }
 
 =head2	fd
@@ -92,7 +91,7 @@ sub fd {
 
 =head2	close
 
-Shouldn't be needed as close happens automatically when there variable goes out of scope.
+Shouldn't be needed as close happens automatically when the variable goes out of scope.
 However Perl isn't as good at reaping as it'd have you believe, so this is here to force it when you
 know you're finished with the object.
 
@@ -101,17 +100,14 @@ know you're finished with the object.
 sub close {
 	my $self = shift;
 
-	if(my $fd = $self->{'fd'}) {
+	if(my $fd = delete $self->{'fd'}) {
 		# my @statb = stat($fd);
 		# IO::AIO::fadvise($fd, 0, $statb[7] - 1, IO::AIO::FADV_DONTNEED);
 		IO::AIO::fadvise($fd, 0, 0, IO::AIO::FADV_DONTNEED);
 
 		close $fd;
-
-		delete $self->{'fd'};
-	# } else {
-		# Seems to get false positives
-		# Carp::carp('Attempt to close object twice');
+	} else {
+		Carp::carp('Attempt to close object twice');
 	}
 }
 
@@ -153,10 +149,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Open-NoCache-ReadOnly>
 
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/File-Open-NoCache-ReadOnly>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/File-Open-NoCache-ReadOnly/>
@@ -165,7 +157,7 @@ L<http://search.cpan.org/dist/File-Open-NoCache-ReadOnly/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2019 Nigel Horne.
+Copyright 2019-2024 Nigel Horne.
 
 Usage is subject to licence terms.
 
